@@ -24,7 +24,7 @@ ly_bar <- function(
   color = NULL, alpha = 1,
   position = c("stack", "fill", "dodge"), width = 0.9, hover = FALSE,
   origin = NULL, breaks = NULL, right = FALSE, binwidth = NULL,
-  lname = NULL, lgroup = NULL, legend = NULL, visible = TRUE, ...
+  lname = NULL, lgroup = NULL, legend = NULL, ...
 ) {
 
   position <- match.arg(position)
@@ -47,7 +47,6 @@ ly_bar <- function(
       legend,
       lname,
       lgroup,
-      visible,
       dots = lazy_dots(...)
     )
   )
